@@ -41,7 +41,8 @@ class UniversalDependencyRelation(DependencyRelation):
                                 "COMPOUND:LVC", "COMPOUND:REDUP",
                                 "CSUBJ:COP", "NMOD:COMP",
                                 "NMOD:PART", "NSUBJ:COP",
-                                "OBL:AGENT", "OBL:TMOD"]
+                                "OBL:AGENT", "OBL:TMOD",
+                                "OBL:NPMOD"]
 
     universalDependencyTags = [UniversalDependencyType.ACL, UniversalDependencyType.ADVCL,
                                UniversalDependencyType.ADVMOD, UniversalDependencyType.AMOD,
@@ -66,8 +67,7 @@ class UniversalDependencyRelation(DependencyRelation):
                                UniversalDependencyType.REPARANDUM, UniversalDependencyType.ROOT,
                                UniversalDependencyType.VOCATIVE,
                                UniversalDependencyType.XCOMP, UniversalDependencyType.ACL_RELCL,
-                               UniversalDependencyType.AUX_PASS,
-                               UniversalDependencyType.CC_PRECONJ, UniversalDependencyType.COMPOUND_PRT,
+                               UniversalDependencyType.AUX_PASS, UniversalDependencyType.CC_PRECONJ, UniversalDependencyType.COMPOUND_PRT,
                                UniversalDependencyType.DET_PREDET, UniversalDependencyType.FLAT_FOREIGN,
                                UniversalDependencyType.NSUBJ_PASS, UniversalDependencyType.CSUBJ_PASS,
                                UniversalDependencyType.NMOD_NPMOD, UniversalDependencyType.NMOD_POSS,
@@ -76,7 +76,7 @@ class UniversalDependencyRelation(DependencyRelation):
                                UniversalDependencyType.COMPOUND_REDUP, UniversalDependencyType.CSUBJ_COP,
                                UniversalDependencyType.NMOD_COMP, UniversalDependencyType.NMOD_PART,
                                UniversalDependencyType.NSUBJ_COP, UniversalDependencyType.OBL_AGENT,
-                               UniversalDependencyType.OBL_TMOD]
+                               UniversalDependencyType.OBL_TMOD, UniversalDependencyType.OBL_NPMOD]
 
     universalDependencyPosTypes = ["ADJ", "ADV", "INTJ", "NOUN", "PROPN", "VERB", "ADP", "AUX", "CCONJ",
                                    "DET", "NUM", "PART", "PRON", "SCONJ", "PUNCT", "SYM", "X"]
